<?php
/**
* Posts Summaries options
*
* @package GridSoul WordPress Theme
* @copyright Copyright (C) 2024 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

function gridsoul_posts_grid_options($wp_customize) {

    $wp_customize->add_section( 'gridsoul_section_posts_summaries', array( 'title' => esc_html__( 'Posts Grid Options', 'gridsoul' ), 'description' => esc_html__('To display your latest posts as a grid on your homepage, please set the "Your homepage displays" option to "Your latest posts." You can find this setting in your WordPress Dashboard by navigating to "Settings" -> "Reading" -> "Your homepage displays."', 'gridsoul'), 'panel' => 'gridsoul_main_options_panel', 'priority' => 160 ) );

    $wp_customize->add_setting( 'gridsoul_options[hide_posts_heading]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_hide_posts_heading_control', array( 'label' => esc_html__( 'Hide HomePage Posts Heading', 'gridsoul' ), 'section' => 'gridsoul_section_posts_summaries', 'settings' => 'gridsoul_options[hide_posts_heading]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[posts_heading]', array( 'default' => esc_html__( 'Recent Posts', 'gridsoul' ), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'sanitize_text_field', ) );

    $wp_customize->add_control( 'gridsoul_posts_heading_control', array( 'label' => esc_html__( 'HomePage Posts Heading', 'gridsoul' ), 'section' => 'gridsoul_section_posts_summaries', 'settings' => 'gridsoul_options[posts_heading]', 'type' => 'text', ) );

    $wp_customize->add_setting( 'posts_per_page', array( 'default' => get_option('posts_per_page'), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_positive_integer' ) );

    $wp_customize->add_control( 'gridsoul_posts_per_page_control', array( 'label' => esc_html__( 'Number of Posts per Page', 'gridsoul' ), 'description' => esc_html__('Set the maximum number of posts displayed on each blog page.', 'gridsoul'), 'section' => 'gridsoul_section_posts_summaries', 'settings' => 'posts_per_page', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[post_summaries_style]', array( 'default' => 'grid', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_post_summaries_style' ) );

    $wp_customize->add_control( 'gridsoul_post_summaries_style_control', array( 'label' => esc_html__( 'Post Summaries Style', 'gridsoul' ), 'description' => esc_html__('Select the post summaries style for non-singular pages.', 'gridsoul'), 'section' => 'gridsoul_section_posts_summaries', 'settings' => 'gridsoul_options[post_summaries_style]', 'type' => 'select', 'choices' => array( 'grid' => esc_html__('Grid Posts', 'gridsoul'), 'non-grid' => esc_html__('Non-Grid Posts', 'gridsoul') ) ) );

    $wp_customize->add_setting( 'gridsoul_options[center_grid_content]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_center_grid_content_control', array( 'label' => esc_html__( 'Center the Content of Grid Post Summaries', 'gridsoul' ), 'section' => 'gridsoul_section_posts_summaries', 'settings' => 'gridsoul_options[center_grid_content]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[hide_thumbnail_home]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_hide_thumbnail_home_control', array( 'label' => esc_html__( 'Hide Featured Images from Grid | Non-Grid Posts Summaries', 'gridsoul' ), 'section' => 'gridsoul_section_posts_summaries', 'settings' => 'gridsoul_options[hide_thumbnail_home]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[hide_default_thumbnail]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_hide_default_thumbnail_control', array( 'label' => esc_html__( 'Hide Default Featured Image from Grid Posts Summaries', 'gridsoul' ), 'description' => esc_html__( 'The default thumbnail image is shown when there is no featured image is set.', 'gridsoul' ), 'section' => 'gridsoul_section_posts_summaries', 'settings' => 'gridsoul_options[hide_default_thumbnail]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[featured_nongrid_media_under_post_title]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_featured_nongrid_media_under_post_title_control', array( 'label' => esc_html__( 'Move Featured Images to the Bottom of Post Titles on Non-Grid Post Summaries', 'gridsoul' ), 'section' => 'gridsoul_section_posts_summaries', 'settings' => 'gridsoul_options[featured_nongrid_media_under_post_title]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[nongrid_thumb_style]', array( 'default' => 'gridsoul-805w-autoh-image', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_nongrid_thumb_style' ) );

    $wp_customize->add_control( 'gridsoul_nongrid_thumb_style_control', array( 'label' => esc_html__( 'Featured Images Size of Non-Grid Posts Summaries', 'gridsoul' ), 'description' => esc_html__('Select the thumbnail size you need for the non-grid post summaries.', 'gridsoul'), 'section' => 'gridsoul_section_posts_summaries', 'settings' => 'gridsoul_options[nongrid_thumb_style]', 'type' => 'select', 'choices' => array( 'gridsoul-805w-430h-image' => esc_html__( '805:430 Thumbnails', 'gridsoul' ), 'gridsoul-805w-autoh-image' => esc_html__( '805:Auto Thumbnails', 'gridsoul' ), 'full' => esc_html__( 'Original Size', 'gridsoul' ) ) ) );

    $wp_customize->add_setting( 'gridsoul_options[thumbnail_link_home]', array( 'default' => 'yes', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_yes_no' ) );

    $wp_customize->add_control( 'gridsoul_thumbnail_link_home_control', array( 'label' => esc_html__( 'Featured Images Links', 'gridsoul' ), 'description' => esc_html__('Do you want thumbnails in grid | non-grid posts summaries to be linked to their posts?', 'gridsoul'), 'section' => 'gridsoul_section_posts_summaries', 'settings' => 'gridsoul_options[thumbnail_link_home]', 'type' => 'select', 'choices' => array( 'yes' => esc_html__('Yes', 'gridsoul'), 'no' => esc_html__('No', 'gridsoul') ) ) );

   $wp_customize->add_setting( 'gridsoul_options[hide_post_header_home]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_hide_post_header_home_control', array( 'label' => esc_html__( 'Hide Post Headers from Non-Grid Posts Summaries', 'gridsoul' ), 'description' => esc_html__('If you check this option, it will hide both post titles and post header meta data from non-grid posts summaries.', 'gridsoul'), 'section' => 'gridsoul_section_posts_summaries', 'settings' => 'gridsoul_options[hide_post_header_home]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[hide_post_title_home]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_hide_post_title_home_control', array( 'label' => esc_html__( 'Hide Post Titles from Grid | Non-Grid Posts Summaries', 'gridsoul' ), 'section' => 'gridsoul_section_posts_summaries', 'settings' => 'gridsoul_options[hide_post_title_home]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[remove_post_title_link_home]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_remove_post_title_link_home_control', array( 'label' => esc_html__( 'Remove Links of Post Titles from Grid | Non-Grid Posts Summaries', 'gridsoul' ), 'section' => 'gridsoul_section_posts_summaries', 'settings' => 'gridsoul_options[remove_post_title_link_home]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[limit_post_titles_home]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_limit_post_titles_home_control', array( 'label' => esc_html__( 'Limit the Length of Post Titles in Grid Posts Summaries', 'gridsoul' ), 'section' => 'gridsoul_section_posts_summaries', 'settings' => 'gridsoul_options[limit_post_titles_home]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[post_title_length_home]', array( 'default' => 6, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_positive_integer' ) );

    $wp_customize->add_control( 'gridsoul_post_title_length_home_control', array( 'label' => esc_html__( 'Maximum Length of Post Titles in Grid Posts Summaries', 'gridsoul' ), 'description' => esc_html__('Enter the maximum number of words need to display in grid post titles. Default is 8 words. This option only work if you have check the option "Limit the Length of Post Titles in Grid Posts Summaries".', 'gridsoul'), 'section' => 'gridsoul_section_posts_summaries', 'settings' => 'gridsoul_options[post_title_length_home]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[hide_post_author_home]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_hide_post_author_home_control', array( 'label' => esc_html__( 'Hide Post Author Names from Grid | Non-Grid Posts Summaries', 'gridsoul' ), 'section' => 'gridsoul_section_posts_summaries', 'settings' => 'gridsoul_options[hide_post_author_home]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[hide_posted_date_home]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_hide_posted_date_home_control', array( 'label' => esc_html__( 'Hide Posted Dates from Grid | Non-Grid Posts Summaries', 'gridsoul' ), 'section' => 'gridsoul_section_posts_summaries', 'settings' => 'gridsoul_options[hide_posted_date_home]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[show_comments_link_home]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_show_comments_link_home_control', array( 'label' => esc_html__( 'Show Comments Links on Grid | Non-Grid Posts Summaries', 'gridsoul' ), 'section' => 'gridsoul_section_posts_summaries', 'settings' => 'gridsoul_options[show_comments_link_home]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[hide_post_categories_home]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_hide_post_categories_home_control', array( 'label' => esc_html__( 'Hide Post Categories from Grid | Non-Grid Posts Summaries', 'gridsoul' ), 'section' => 'gridsoul_section_posts_summaries', 'settings' => 'gridsoul_options[hide_post_categories_home]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[hide_post_tags_home]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_hide_post_tags_home_control', array( 'label' => esc_html__( 'Hide Post Tags from Non-Grid Posts Summaries', 'gridsoul' ), 'section' => 'gridsoul_section_posts_summaries', 'settings' => 'gridsoul_options[hide_post_tags_home]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[hide_post_snippet]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_hide_post_snippet_control', array( 'label' => esc_html__( 'Hide Post Snippets from Grid Posts Summaries', 'gridsoul' ), 'section' => 'gridsoul_section_posts_summaries', 'settings' => 'gridsoul_options[hide_post_snippet]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[grid_snippet_type]', array( 'default' => 'postexcerpt', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_snippet_type' ) );

    $wp_customize->add_control( 'gridsoul_grid_snippet_type_control', array( 'label' => esc_html__( 'Post Snippets Type of Grid Posts Summaries', 'gridsoul' ), 'section' => 'gridsoul_section_posts_summaries', 'settings' => 'gridsoul_options[grid_snippet_type]', 'type' => 'select', 'choices' => array( 'postexcerpt' => esc_html__('Post Excerpt', 'gridsoul'), 'postcontent' => esc_html__('Post Content', 'gridsoul') ) ) );

    $wp_customize->add_setting( 'gridsoul_options[read_more_length]', array( 'default' => 17, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_read_more_length' ) );

    $wp_customize->add_control( 'gridsoul_read_more_length_control', array( 'label' => esc_html__( 'Auto Post Summary Length', 'gridsoul' ), 'description' => esc_html__('Enter the number of words need to display in the post summary. Default is 20 words.', 'gridsoul'), 'section' => 'gridsoul_section_posts_summaries', 'settings' => 'gridsoul_options[read_more_length]', 'type' => 'text' ) );

}