<?php
/**
* Page options
*
* @package GridSoul WordPress Theme
* @copyright Copyright (C) 2024 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

function gridsoul_page_options($wp_customize) {

    $wp_customize->add_section( 'gridsoul_section_page', array( 'title' => esc_html__( 'Singular Page Options', 'gridsoul' ), 'panel' => 'gridsoul_main_options_panel', 'priority' => 185 ) );

    $wp_customize->add_setting( 'gridsoul_options[page_thumb_style]', array( 'default' => 'gridsoul-805w-autoh-image', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_page_thumb_style' ) );

    $wp_customize->add_control( 'gridsoul_page_thumb_style_control', array( 'label' => esc_html__( 'Featured Image Size of Single Page', 'gridsoul' ), 'description' => esc_html__('Select the thumbnail size you need inside single pages.', 'gridsoul'), 'section' => 'gridsoul_section_page', 'settings' => 'gridsoul_options[page_thumb_style]', 'type' => 'select', 'choices' => array( 'gridsoul-805w-430h-image' => esc_html__( '805:430 Thumbnails', 'gridsoul' ), 'gridsoul-805w-autoh-image' => esc_html__( '805:Auto Thumbnails', 'gridsoul' ), 'full' => esc_html__( 'Original Size', 'gridsoul' ) ) ) );

    $wp_customize->add_setting( 'gridsoul_options[thumbnail_link_page]', array( 'default' => 'yes', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_yes_no' ) );

    $wp_customize->add_control( 'gridsoul_thumbnail_link_page_control', array( 'label' => esc_html__( 'Featured Image Link', 'gridsoul' ), 'description' => esc_html__('Do you want the featured image in a page to be linked to its page?', 'gridsoul'), 'section' => 'gridsoul_section_page', 'settings' => 'gridsoul_options[thumbnail_link_page]', 'type' => 'select', 'choices' => array( 'yes' => esc_html__('Yes', 'gridsoul'), 'no' => esc_html__('No', 'gridsoul') ) ) );

    $wp_customize->add_setting( 'gridsoul_options[hide_page_thumbnail]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_hide_page_thumbnail_control', array( 'label' => esc_html__( 'Hide Featured Image from Single Page', 'gridsoul' ), 'section' => 'gridsoul_section_page', 'settings' => 'gridsoul_options[hide_page_thumbnail]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[featured_media_under_page_title]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_featured_media_under_page_title_control', array( 'label' => esc_html__( 'Move Featured Image to Bottom of Page Title', 'gridsoul' ), 'section' => 'gridsoul_section_page', 'settings' => 'gridsoul_options[featured_media_under_page_title]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[hide_page_header]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_hide_page_header_control', array( 'label' => esc_html__( 'Hide Page Header from Single Page', 'gridsoul' ), 'description' => esc_html__('If you check this option, it will hide page title and page header meta data from single page.', 'gridsoul'), 'section' => 'gridsoul_section_page', 'settings' => 'gridsoul_options[hide_page_header]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[hide_page_title]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_hide_page_title_control', array( 'label' => esc_html__( 'Hide Page Header from Single Page', 'gridsoul' ), 'section' => 'gridsoul_section_page', 'settings' => 'gridsoul_options[hide_page_title]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[remove_page_title_link]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_remove_page_title_link_control', array( 'label' => esc_html__( 'Remove Link from Single Page Title', 'gridsoul' ), 'section' => 'gridsoul_section_page', 'settings' => 'gridsoul_options[remove_page_title_link]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[hide_page_date]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_hide_page_date_control', array( 'label' => esc_html__( 'Hide Posted Date from Single Page', 'gridsoul' ), 'section' => 'gridsoul_section_page', 'settings' => 'gridsoul_options[hide_page_date]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[hide_page_author]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_hide_page_author_control', array( 'label' => esc_html__( 'Hide Page Author from Single Page', 'gridsoul' ), 'section' => 'gridsoul_section_page', 'settings' => 'gridsoul_options[hide_page_author]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[hide_page_comments]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_hide_page_comments_control', array( 'label' => esc_html__( 'Hide Comment Link from Single Page', 'gridsoul' ), 'section' => 'gridsoul_section_page', 'settings' => 'gridsoul_options[hide_page_comments]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[hide_page_comment_form]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_hide_page_comment_form_control', array( 'label' => esc_html__( 'Hide Comments/Comment Form from Single Pages', 'gridsoul' ), 'section' => 'gridsoul_section_page', 'settings' => 'gridsoul_options[hide_page_comment_form]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[hide_page_edit]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_hide_page_edit_control', array( 'label' => esc_html__( 'Hide Edit Link from Single Page', 'gridsoul' ), 'section' => 'gridsoul_section_page', 'settings' => 'gridsoul_options[hide_page_edit]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[hide_static_page_title]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_hide_static_page_title_control', array( 'label' => esc_html__( 'Hide Page Header from Static Homepage', 'gridsoul' ), 'section' => 'gridsoul_section_page', 'settings' => 'gridsoul_options[hide_static_page_title]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[hide_static_page_meta]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_hide_static_page_meta_control', array( 'label' => esc_html__( 'Hide Page Meta Data (Page Date, Page Author, Comment Link) from Static Homepage', 'gridsoul' ), 'section' => 'gridsoul_section_page', 'settings' => 'gridsoul_options[hide_static_page_meta]', 'type' => 'checkbox', ) );

}