<?php
/**
* Post options
*
* @package GridSoul WordPress Theme
* @copyright Copyright (C) 2024 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

function gridsoul_post_options($wp_customize) {

    $wp_customize->add_section( 'gridsoul_section_post', array( 'title' => esc_html__( 'Singular Post Options', 'gridsoul' ), 'panel' => 'gridsoul_main_options_panel', 'priority' => 180 ) );

    $wp_customize->add_setting( 'gridsoul_options[single_thumb_style]', array( 'default' => 'gridsoul-805w-autoh-image', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_single_thumb_style' ) );

    $wp_customize->add_control( 'gridsoul_single_thumb_style_control', array( 'label' => esc_html__( 'Featured Image Size of Full Post', 'gridsoul' ), 'description' => esc_html__('Select the thumbnail size you need inside full posts.', 'gridsoul'), 'section' => 'gridsoul_section_post', 'settings' => 'gridsoul_options[single_thumb_style]', 'type' => 'select', 'choices' => array( 'gridsoul-805w-430h-image' => esc_html__( '805:430 Thumbnails', 'gridsoul' ), 'gridsoul-805w-autoh-image' => esc_html__( '805:Auto Thumbnails', 'gridsoul' ), 'full' => esc_html__( 'Original Size', 'gridsoul' ) ) ) );

    $wp_customize->add_setting( 'gridsoul_options[thumbnail_link]', array( 'default' => 'yes', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_yes_no' ) );

    $wp_customize->add_control( 'gridsoul_thumbnail_link_control', array( 'label' => esc_html__( 'Featured Image Link', 'gridsoul' ), 'description' => esc_html__('Do you want the featured image in a single post to be linked to its post?', 'gridsoul'), 'section' => 'gridsoul_section_post', 'settings' => 'gridsoul_options[thumbnail_link]', 'type' => 'select', 'choices' => array( 'yes' => esc_html__('Yes', 'gridsoul'), 'no' => esc_html__('No', 'gridsoul') ) ) );

    $wp_customize->add_setting( 'gridsoul_options[hide_thumbnail]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_hide_thumbnail_control', array( 'label' => esc_html__( 'Hide Featured Image from Full Post', 'gridsoul' ), 'section' => 'gridsoul_section_post', 'settings' => 'gridsoul_options[hide_thumbnail]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[featured_media_under_post_title]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_featured_media_under_post_title_control', array( 'label' => esc_html__( 'Move Featured Image to Bottom of Full Post Title', 'gridsoul' ), 'section' => 'gridsoul_section_post', 'settings' => 'gridsoul_options[featured_media_under_post_title]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[auto_width_thumbnail]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_auto_width_thumbnail_control', array( 'label' => esc_html__( 'Do not Stretch Small Featured Image in Full Post', 'gridsoul' ), 'section' => 'gridsoul_section_post', 'settings' => 'gridsoul_options[auto_width_thumbnail]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[hide_post_title]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_hide_post_title_control', array( 'label' => esc_html__( 'Hide Post Header from Full Post', 'gridsoul' ), 'section' => 'gridsoul_section_post', 'settings' => 'gridsoul_options[hide_post_title]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[remove_post_title_link]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_remove_post_title_link_control', array( 'label' => esc_html__( 'Remove Link from Full Post Title', 'gridsoul' ), 'section' => 'gridsoul_section_post', 'settings' => 'gridsoul_options[remove_post_title_link]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[hide_post_categories]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_hide_post_categories_control', array( 'label' => esc_html__( 'Hide Post Categories from Full Post', 'gridsoul' ), 'section' => 'gridsoul_section_post', 'settings' => 'gridsoul_options[hide_post_categories]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[hide_post_author]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_hide_post_author_control', array( 'label' => esc_html__( 'Hide Post Author from Full Post', 'gridsoul' ), 'section' => 'gridsoul_section_post', 'settings' => 'gridsoul_options[hide_post_author]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[hide_posted_date]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_hide_posted_date_control', array( 'label' => esc_html__( 'Hide Posted Date from Full Post', 'gridsoul' ), 'section' => 'gridsoul_section_post', 'settings' => 'gridsoul_options[hide_posted_date]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[hide_comments_link]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_hide_comments_link_control', array( 'label' => esc_html__( 'Hide Comment Link from Full Post', 'gridsoul' ), 'section' => 'gridsoul_section_post', 'settings' => 'gridsoul_options[hide_comments_link]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[hide_comment_form]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_hide_comment_form_control', array( 'label' => esc_html__( 'Hide Comments/Comment Form from Single Posts', 'gridsoul' ), 'section' => 'gridsoul_section_post', 'settings' => 'gridsoul_options[hide_comment_form]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[show_post_edit]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_show_post_edit_control', array( 'label' => esc_html__( 'Show Post Edit Link', 'gridsoul' ), 'section' => 'gridsoul_section_post', 'settings' => 'gridsoul_options[show_post_edit]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[hide_post_tags]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_hide_post_tags_control', array( 'label' => esc_html__( 'Hide Post Tags from Full Post', 'gridsoul' ), 'section' => 'gridsoul_section_post', 'settings' => 'gridsoul_options[hide_post_tags]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[hide_author_bio_box]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_hide_author_bio_box_control', array( 'label' => esc_html__( 'Hide Author Bio Box', 'gridsoul' ), 'section' => 'gridsoul_section_post', 'settings' => 'gridsoul_options[hide_author_bio_box]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[no_underline_content_links]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_no_underline_content_links_control', array( 'label' => esc_html__( 'Do not Underline the Links within the Content', 'gridsoul' ), 'section' => 'gridsoul_section_post', 'settings' => 'gridsoul_options[no_underline_content_links]', 'type' => 'checkbox', ) );

}