<?php
/**
* Social profiles options
*
* @package GridSoul WordPress Theme
* @copyright Copyright (C) 2024 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

function gridsoul_social_profiles($wp_customize) {

    $wp_customize->add_section( 'gridsoul_section_social', array( 'title' => esc_html__( 'Social Buttons Options', 'gridsoul' ), 'panel' => 'gridsoul_main_options_panel', 'priority' => 240, ));

    $wp_customize->add_setting( 'gridsoul_options[hide_social_buttons]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_hide_social_buttons_control', array( 'label' => esc_html__( 'Hide Header Social + Login/Logout Buttons', 'gridsoul' ), 'description' => esc_html__('If you checked this option, all buttons will disappear from header. There is no any effect from these option: "Show Login/Logout Button in Header".', 'gridsoul'), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[hide_social_buttons]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[show_login_button]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_show_login_button_control', array( 'label' => esc_html__( 'Show Login/Logout Button in Header', 'gridsoul' ), 'description' => esc_html__('This option has no effect if you checked the option: "Hide Header Social + Login/Logout Buttons"', 'gridsoul'), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[show_login_button]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[hide_social_search]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridsoul_hide_social_search_control', array( 'label' => esc_html__( 'Hide Search Box from Social Area', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[hide_social_search]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridsoul_options[twitterlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_twitterlink_control', array( 'label' => esc_html__( 'X URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[twitterlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[facebooklink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_facebooklink_control', array( 'label' => esc_html__( 'Facebook URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[facebooklink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[threadslink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_threadslink_control', array( 'label' => esc_html__( 'Threads URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[threadslink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[pinterestlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_pinterestlink_control', array( 'label' => esc_html__( 'Pinterest URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[pinterestlink]', 'type' => 'text' ) );
    
    $wp_customize->add_setting( 'gridsoul_options[linkedinlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_linkedinlink_control', array( 'label' => esc_html__( 'Linkedin Link', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[linkedinlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[instagramlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_instagramlink_control', array( 'label' => esc_html__( 'Instagram Link', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[instagramlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[vklink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_vklink_control', array( 'label' => esc_html__( 'VK Link', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[vklink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[flickrlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_flickrlink_control', array( 'label' => esc_html__( 'Flickr Link', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[flickrlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[youtubelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_youtubelink_control', array( 'label' => esc_html__( 'Youtube URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[youtubelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[vimeolink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_vimeolink_control', array( 'label' => esc_html__( 'Vimeo URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[vimeolink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[soundcloudlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_soundcloudlink_control', array( 'label' => esc_html__( 'Soundcloud URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[soundcloudlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[messengerlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_messengerlink_control', array( 'label' => esc_html__( 'Messenger URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[messengerlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[whatsapplink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_whatsapplink_control', array( 'label' => esc_html__( 'WhatsApp URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[whatsapplink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[tiktoklink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_tiktoklink_control', array( 'label' => esc_html__( 'TikTok URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[tiktoklink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[lastfmlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_lastfmlink_control', array( 'label' => esc_html__( 'Lastfm URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[lastfmlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[mediumlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_mediumlink_control', array( 'label' => esc_html__( 'Medium URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[mediumlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[githublink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_githublink_control', array( 'label' => esc_html__( 'Github URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[githublink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[bitbucketlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_bitbucketlink_control', array( 'label' => esc_html__( 'Bitbucket URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[bitbucketlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[tumblrlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_tumblrlink_control', array( 'label' => esc_html__( 'Tumblr URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[tumblrlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[digglink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_digglink_control', array( 'label' => esc_html__( 'Digg URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[digglink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[deliciouslink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_deliciouslink_control', array( 'label' => esc_html__( 'Delicious URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[deliciouslink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[stumblelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_stumblelink_control', array( 'label' => esc_html__( 'Stumbleupon URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[stumblelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[mixlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_mixlink_control', array( 'label' => esc_html__( 'Mix URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[mixlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[redditlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_redditlink_control', array( 'label' => esc_html__( 'Reddit URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[redditlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[dribbblelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_dribbblelink_control', array( 'label' => esc_html__( 'Dribbble URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[dribbblelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[flipboardlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_flipboardlink_control', array( 'label' => esc_html__( 'Flipboard URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[flipboardlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[bloggerlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_bloggerlink_control', array( 'label' => esc_html__( 'Blogger URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[bloggerlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[etsylink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_etsylink_control', array( 'label' => esc_html__( 'Etsy URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[etsylink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[behancelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_behancelink_control', array( 'label' => esc_html__( 'Behance URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[behancelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[amazonlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_amazonlink_control', array( 'label' => esc_html__( 'Amazon URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[amazonlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[meetuplink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_meetuplink_control', array( 'label' => esc_html__( 'Meetup URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[meetuplink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[mixcloudlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_mixcloudlink_control', array( 'label' => esc_html__( 'Mixcloud URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[mixcloudlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[slacklink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_slacklink_control', array( 'label' => esc_html__( 'Slack URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[slacklink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[snapchatlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_snapchatlink_control', array( 'label' => esc_html__( 'Snapchat URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[snapchatlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[spotifylink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_spotifylink_control', array( 'label' => esc_html__( 'Spotify URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[spotifylink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[yelplink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_yelplink_control', array( 'label' => esc_html__( 'Yelp URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[yelplink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[wordpresslink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_wordpresslink_control', array( 'label' => esc_html__( 'WordPress URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[wordpresslink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[twitchlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_twitchlink_control', array( 'label' => esc_html__( 'Twitch URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[twitchlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[telegramlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_telegramlink_control', array( 'label' => esc_html__( 'Telegram URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[telegramlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[bandcamplink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_bandcamplink_control', array( 'label' => esc_html__( 'Bandcamp URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[bandcamplink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[quoralink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_quoralink_control', array( 'label' => esc_html__( 'Quora URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[quoralink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[foursquarelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_foursquarelink_control', array( 'label' => esc_html__( 'Foursquare URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[foursquarelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[deviantartlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_deviantartlink_control', array( 'label' => esc_html__( 'DeviantArt URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[deviantartlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[imdblink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_imdblink_control', array( 'label' => esc_html__( 'IMDB URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[imdblink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[codepenlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_codepenlink_control', array( 'label' => esc_html__( 'Codepen URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[codepenlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[jsfiddlelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_jsfiddlelink_control', array( 'label' => esc_html__( 'JSFiddle URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[jsfiddlelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[stackoverflowlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_stackoverflowlink_control', array( 'label' => esc_html__( 'Stack Overflow URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[stackoverflowlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[stackexchangelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_stackexchangelink_control', array( 'label' => esc_html__( 'Stack Exchange URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[stackexchangelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[bsalink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_bsalink_control', array( 'label' => esc_html__( 'BuySellAds URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[bsalink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[web500pxlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_web500pxlink_control', array( 'label' => esc_html__( '500px URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[web500pxlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[ellolink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_ellolink_control', array( 'label' => esc_html__( 'Ello URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[ellolink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[discordlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_discordlink_control', array( 'label' => esc_html__( 'Discord URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[discordlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[goodreadslink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_goodreadslink_control', array( 'label' => esc_html__( 'Goodreads URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[goodreadslink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[odnoklassnikilink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_odnoklassnikilink_control', array( 'label' => esc_html__( 'Odnoklassniki URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[odnoklassnikilink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[houzzlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_houzzlink_control', array( 'label' => esc_html__( 'Houzz URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[houzzlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[pocketlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_pocketlink_control', array( 'label' => esc_html__( 'Pocket URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[pocketlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[xinglink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_xinglink_control', array( 'label' => esc_html__( 'XING URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[xinglink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[mastodonlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_mastodonlink_control', array( 'label' => esc_html__( 'Mastodon URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[mastodonlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[googleplaylink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_googleplaylink_control', array( 'label' => esc_html__( 'Google Play URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[googleplaylink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[slidesharelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_slidesharelink_control', array( 'label' => esc_html__( 'SlideShare URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[slidesharelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[dropboxlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_dropboxlink_control', array( 'label' => esc_html__( 'Dropbox URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[dropboxlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[paypallink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_paypallink_control', array( 'label' => esc_html__( 'PayPal URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[paypallink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[viadeolink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_viadeolink_control', array( 'label' => esc_html__( 'Viadeo URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[viadeolink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[wikipedialink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_wikipedialink_control', array( 'label' => esc_html__( 'Wikipedia URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[wikipedialink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[skypeusername]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'sanitize_text_field' ) );

    $wp_customize->add_control( 'gridsoul_skypeusername_control', array( 'label' => esc_html__( 'Skype Username', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[skypeusername]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[emailaddress]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridsoul_sanitize_email' ) );

    $wp_customize->add_control( 'gridsoul_emailaddress_control', array( 'label' => esc_html__( 'Email Address', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[emailaddress]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridsoul_options[rsslink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridsoul_rsslink_control', array( 'label' => esc_html__( 'RSS Feed URL', 'gridsoul' ), 'section' => 'gridsoul_section_social', 'settings' => 'gridsoul_options[rsslink]', 'type' => 'text' ) );

}