<?php
/**
* Enqueue scripts and styles
*
* @package GridSoul WordPress Theme
* @copyright Copyright (C) 2024 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

function gridsoul_scripts() {
    wp_enqueue_style('gridsoul-maincss', get_stylesheet_uri(), array(), null);
    wp_enqueue_style('fontawesome', get_template_directory_uri() . '/assets/css/all.min.css', array(), null );
    wp_enqueue_style('gridsoul-webfont', '//fonts.googleapis.com/css?family=Roboto+Condensed:400,400i,700,700i|Poppins:400,400i,500,500i,700,700i&amp;display=swap', array(), null);

    $gridsoul_fitvids_active = false;
    if ( gridsoul_is_fitvids_active() ) {
        $gridsoul_fitvids_active = true;
    }
    if ( $gridsoul_fitvids_active ) {
        wp_enqueue_script('fitvids', get_template_directory_uri() .'/assets/js/jquery.fitvids.min.js', array( 'jquery' ), null, true);
    }

    $gridsoul_backtotop_active = false;
    if ( gridsoul_is_backtotop_active() ) {
        $gridsoul_backtotop_active = true;
    }

    $gridsoul_primary_menu_active = false;
    if ( gridsoul_is_primary_menu_active() ) {
        $gridsoul_primary_menu_active = true;
    }

    $gridsoul_sticky_sidebar_active = true;
    if ( is_singular() ) {
        if ( is_page_template( array( 'template-full-width-page.php', 'template-full-width-post.php' ) ) ) {
           $gridsoul_sticky_sidebar_active = false;
        }
    } else {
        $gridsoul_sticky_sidebar_active = false;
    }
    if ( $gridsoul_sticky_sidebar_active ) {
        wp_enqueue_script('ResizeSensor', get_template_directory_uri() .'/assets/js/ResizeSensor.min.js', array( 'jquery' ), null, true);
        wp_enqueue_script('theia-sticky-sidebar', get_template_directory_uri() .'/assets/js/theia-sticky-sidebar.min.js', array( 'jquery' ), null, true);
    }

    $gridsoul_slider_active = false;
    if ( gridsoul_is_slider_active() ) {
        if ( 'front-page' === gridsoul_get_option('slider_display') ) {
            if ( is_front_page() && is_home() && !is_paged() ) {
                $gridsoul_slider_active = true;
            }
        } elseif ( 'front-page-static' === gridsoul_get_option('slider_display') ) {
            if ( is_front_page() && is_singular() ) {
                $gridsoul_slider_active = true;
            }
        } elseif ( 'blog-posts-index' === gridsoul_get_option('slider_display') ) {
            if ( is_home() && !is_paged() ) {
                $gridsoul_slider_active = true;
            }
        } else {
            if ( is_front_page() && is_home() && !is_paged() ) {
                $gridsoul_slider_active = true;
            }
        }
    }
    if ( $gridsoul_slider_active ) {
        wp_enqueue_style('owl-carousel', get_template_directory_uri() . '/assets/css/owl.carousel.min.css', array(), null );
        wp_enqueue_script('owl-carousel', get_template_directory_uri() .'/assets/js/owl.carousel.min.js', array( 'jquery', 'imagesloaded' ), null, true);
    }

    $gridsoul_slider_autoplay = false;
    if ( gridsoul_get_option('slider_autoplay') ) {
        $gridsoul_slider_autoplay = true;
    }
    $gridsoul_slider_loop = false;
    if ( gridsoul_get_option('slider_loop') ) {
        $gridsoul_slider_loop = true;
    }
    $gridsoul_slider_autoplayhoverpause = false;
    if ( gridsoul_get_option('slider_autoplayhoverpause') ) {
        $gridsoul_slider_autoplayhoverpause = true;
    }
    $gridsoul_slider_autoplaytimeout = 1000;
    if ( gridsoul_get_option('slider_autoplaytimeout') ) {
        $gridsoul_slider_autoplaytimeout = gridsoul_get_option('slider_autoplaytimeout');
    }
    $gridsoul_slider_autoplayspeed = 200;
    if ( gridsoul_get_option('slider_autoplayspeed') ) {
        $gridsoul_slider_autoplayspeed = gridsoul_get_option('slider_autoplayspeed');
    }
    $gridsoul_show_dots_pagination = false;
    if ( gridsoul_get_option('show_dots_pagination') ) {
        $gridsoul_show_dots_pagination = true;
    }
    $gridsoul_show_next_prev_navigation = true;
    if ( gridsoul_get_option('hide_next_prev_navigation') ) {
        $gridsoul_show_next_prev_navigation = false;
    }

    $gridsoul_autoheight_active = false;
    if ( gridsoul_get_option('enable_autoheight') ) {
        $gridsoul_autoheight_active = true;
    }

    $gridsoul_slider_rtl = false;
    if ( is_rtl() ) {
        $gridsoul_slider_rtl = true;
    }

    wp_enqueue_script('gridsoul-navigation', get_template_directory_uri() . '/assets/js/navigation.js', array(), null, true );
    wp_enqueue_script('gridsoul-skip-link-focus-fix', get_template_directory_uri() . '/assets/js/skip-link-focus-fix.js', array(), null, true );
    wp_enqueue_script('gridsoul-customjs', get_template_directory_uri() .'/assets/js/custom.js', array( 'jquery', 'imagesloaded', 'masonry' ), null, true);

    wp_localize_script( 'gridsoul-customjs', 'gridsoul_ajax_object',
        array(
            'ajaxurl' => esc_url_raw( admin_url( 'admin-ajax.php' ) ),
            'primary_menu_active' => $gridsoul_primary_menu_active,
            'sticky_sidebar_active' => $gridsoul_sticky_sidebar_active,
            'slider_active' => $gridsoul_slider_active,
            'slider_autoplay' => $gridsoul_slider_autoplay,
            'slider_loop' => $gridsoul_slider_loop,
            'slider_autoplayhoverpause' => $gridsoul_slider_autoplayhoverpause,
            'slider_autoplaytimeout' => $gridsoul_slider_autoplaytimeout,
            'slider_autoplayspeed' => $gridsoul_slider_autoplayspeed,
            'show_dots_pagination' => $gridsoul_show_dots_pagination,
            'show_next_prev_navigation' => $gridsoul_show_next_prev_navigation,
            'autoheight_active' => $gridsoul_autoheight_active,
            'slider_rtl' => $gridsoul_slider_rtl,
            'fitvids_active' => $gridsoul_fitvids_active,
            'backtotop_active' => $gridsoul_backtotop_active,
        )
    );

    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
        wp_enqueue_script( 'comment-reply' );
    }

    wp_enqueue_script('gridsoul-html5shiv-js', get_template_directory_uri() .'/assets/js/html5shiv.js', array('jquery'), null, true);

    wp_localize_script('gridsoul-html5shiv-js','gridsoul_custom_script_vars',array(
        'elements_name' => esc_html__('abbr article aside audio bdi canvas data datalist details dialog figcaption figure footer header hgroup main mark meter nav output picture progress section summary template time video', 'gridsoul'),
    ));
}
add_action( 'wp_enqueue_scripts', 'gridsoul_scripts' );

/**
 * Enqueue IE compatible scripts and styles.
 */
function gridsoul_ie_scripts() {
    wp_enqueue_script( 'respond', get_template_directory_uri(). '/assets/js/respond.min.js', array(), null, false );
    wp_script_add_data( 'respond', 'conditional', 'lt IE 9' );
}
add_action( 'wp_enqueue_scripts', 'gridsoul_ie_scripts' );

/**
 * Enqueue styles for the block-based editor.
 */
function gridsoul_block_editor_styles() {
    wp_enqueue_style( 'gridsoul-block-editor-style', get_template_directory_uri() . '/assets/css/editor-blocks.css', array(), null );
}
add_action( 'enqueue_block_editor_assets', 'gridsoul_block_editor_styles' );

/**
 * Enqueue customizer styles.
 */
function gridsoul_enqueue_customizer_styles() {
    wp_enqueue_style( 'gridsoul-customizer-styles', get_template_directory_uri() . '/inc/admin/css/customizer-style.css', array(), null );
    wp_enqueue_style('fontawesome', get_template_directory_uri() . '/assets/css/all.min.css', array(), null );
}
add_action( 'customize_controls_enqueue_scripts', 'gridsoul_enqueue_customizer_styles' );