<?php
/**
* Post meta functions
*
* @package GridSoul WordPress Theme
* @copyright Copyright (C) 2024 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

if ( ! function_exists( 'gridsoul_post_tags' ) ) :
/**
 * Prints HTML with meta information for the tags.
 */
function gridsoul_post_tags() {
    if ( 'post' == get_post_type() ) {
        /* translators: used between list items, there is a space after the comma */
        $tags_list = get_the_tag_list( '', esc_html_x( ', ', 'list item separator', 'gridsoul' ) );
        if ( $tags_list ) {
            /* translators: 1: list of tags. */
            printf( '<span class="gridsoul-tags-links"><i class="fas fa-tags" aria-hidden="true"></i> ' . esc_html__( 'Tagged %1$s', 'gridsoul' ) . '</span>', $tags_list ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
        }
    }
}
endif;


if ( ! function_exists( 'gridsoul_grid_cats' ) ) :
function gridsoul_grid_cats() {
    if ( 'post' == get_post_type() ) {
        /* translators: used between list items, there is a space */
        $categories_list = get_the_category_list( esc_html__( ', ', 'gridsoul' ) );
        if ( $categories_list ) {
            /* translators: 1: list of categories. */
            printf( '<div class="gridsoul-grid-post-categories">' . __( '<span class="gridsoul-sr-only">Posted in </span>%1$s', 'gridsoul' ) . '</div>', $categories_list ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
        }
    }
}
endif;


if ( ! function_exists( 'gridsoul_slider_cats' ) ) :
function gridsoul_slider_cats() {
    global $post;
    if ( 'post' == get_post_type() ) {
        /* translators: used between list items, there is a space */
        $categories_list = get_the_category_list( esc_html__( ', ', 'gridsoul' ) );
        if ( $categories_list ) {
            /* translators: 1: list of categories. */
            printf( '<div class="gridsoul-slider-post-categories gridsoul-slider-post-details-block">' . __( '<span class="gridsoul-sr-only">Posted in </span>%1$s', 'gridsoul' ) . '</div>', $categories_list ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
        }
    }
}
endif;


if ( ! function_exists( 'gridsoul_grid_postmeta' ) ) :
function gridsoul_grid_postmeta() { ?>
    <?php global $post; ?>
    <?php if ( !(gridsoul_get_option('hide_post_author_home')) || !(gridsoul_get_option('hide_posted_date_home')) || gridsoul_get_option('show_comments_link_home') ) { ?>
    <div class="gridsoul-grid-post-footer gridsoul-grid-post-block">
    <?php if ( !(gridsoul_get_option('hide_post_author_home')) ) { ?><span class="gridsoul-grid-post-author gridsoul-grid-post-meta"><a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>"><?php echo esc_html( get_the_author() ); ?></a></span><?php } ?>
   <?php if ( !(gridsoul_get_option('hide_posted_date_home')) ) { ?><span class="gridsoul-grid-post-date gridsoul-grid-post-meta"><?php echo esc_html( get_the_date() ); ?></span><?php } ?>
    <?php if ( gridsoul_get_option('show_comments_link_home') ) { ?><?php if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) { ?><span class="gridsoul-grid-post-comments gridsoul-grid-post-meta"><?php comments_popup_link( sprintf( wp_kses( /* translators: %s: post title */ __( '0 Comment<span class="gridsoul-sr-only"> on %s</span>', 'gridsoul' ), array( 'span' => array( 'class' => array(), ), ) ), wp_kses_post( get_the_title() ) ) ); ?></span><?php } ?><?php } ?>
    </div>
    <?php } ?>
<?php }
endif;


if ( ! function_exists( 'gridsoul_slider_postmeta' ) ) :
function gridsoul_slider_postmeta() { ?>
    <?php global $post; ?>
    <?php if ( !(gridsoul_get_option('hide_posted_date_home')) || (gridsoul_get_option('show_slide_comments') && (! post_password_required() && ( comments_open() || get_comments_number() ))) || !(gridsoul_get_option('hide_post_author_home')) ) { ?>
    <div class="gridsoul-slider-post-footer gridsoul-slider-post-details-block">
    <div class="gridsoul-slider-post-footer-inside">
    <?php if ( !(gridsoul_get_option('hide_post_author_home')) ) { ?><span class="gridsoul-slider-post-author gridsoul-slider-post-meta"><a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>"><?php echo esc_html( get_the_author() ); ?></a></span><?php } ?>
    <?php if ( !(gridsoul_get_option('hide_posted_date_home')) ) { ?><span class="gridsoul-slider-post-date gridsoul-slider-post-meta"><?php echo esc_html( get_the_date() ); ?></span><?php } ?>
    <?php if ( gridsoul_get_option('show_slide_comments') ) { ?><?php if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) { ?>
    <span class="gridsoul-slider-post-comments gridsoul-slider-post-meta"><?php comments_popup_link( sprintf( wp_kses( /* translators: %s: post title */ __( '0 Comment<span class="gridsoul-sr-only"> on %s</span>', 'gridsoul' ), array( 'span' => array( 'class' => array(), ), ) ), wp_kses_post( get_the_title() ) ) ); ?></span>
    <?php } ?><?php } ?>
    </div>
    </div>
    <?php } ?>
<?php }
endif;


if ( ! function_exists( 'gridsoul_nongrid_postmeta' ) ) :
function gridsoul_nongrid_postmeta() { ?>
    <?php global $post; ?>
    <?php if ( !(gridsoul_get_option('hide_post_author_home')) || !(gridsoul_get_option('hide_posted_date_home')) || gridsoul_get_option('show_comments_link_home') || (!(gridsoul_get_option('hide_post_categories_home')) && has_category()) ) { ?>
    <div class="gridsoul-entry-meta-single">
    <?php if ( !(gridsoul_get_option('hide_post_author_home')) ) { ?><span class="gridsoul-entry-meta-single-author"><i class="far fa-user-circle" aria-hidden="true"></i>&nbsp;<span class="author vcard" itemscope="itemscope" itemtype="http://schema.org/Person" itemprop="author"><a class="url fn n" href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>"><?php echo esc_html( get_the_author() ); ?></a></span></span><?php } ?>
    <?php if ( !(gridsoul_get_option('hide_posted_date_home')) ) { ?><span class="gridsoul-entry-meta-single-date"><i class="far fa-clock" aria-hidden="true"></i>&nbsp;<?php echo esc_html( get_the_date() ); ?></span><?php } ?>
    <?php if ( gridsoul_get_option('show_comments_link_home') ) { ?><?php if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) { ?>
    <span class="gridsoul-entry-meta-single-comments"><i class="far fa-comments" aria-hidden="true"></i>&nbsp;<?php comments_popup_link( sprintf( wp_kses( /* translators: %s: post title */ __( 'Leave a Comment<span class="gridsoul-sr-only"> on %s</span>', 'gridsoul' ), array( 'span' => array( 'class' => array(), ), ) ), wp_kses_post( get_the_title() ) ) ); ?></span>
    <?php } ?><?php } ?>
    <?php if ( !(gridsoul_get_option('hide_post_categories_home')) && has_category() ) { ?><?php gridsoul_single_cats(); ?><?php } ?>
    </div>
    <?php } ?>
<?php }
endif;


if ( ! function_exists( 'gridsoul_single_cats' ) ) :
function gridsoul_single_cats() {
    if ( 'post' == get_post_type() ) {
        /* translators: used between list items, there is a space */
        $categories_list = get_the_category_list( esc_html__( ', ', 'gridsoul' ) );
        if ( $categories_list ) {
            /* translators: 1: list of categories. */
            printf( '<span class="gridsoul-entry-meta-single-cats gridsoul-entry-meta-single-block"><i class="far fa-folder-open" aria-hidden="true"></i>&nbsp;' . __( '<span class="gridsoul-sr-only">Posted in </span>%1$s', 'gridsoul' ) . '</span>', $categories_list ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
        }
    }
}
endif;


if ( ! function_exists( 'gridsoul_single_postmeta' ) ) :
function gridsoul_single_postmeta() { ?>
    <?php global $post; ?>
    <?php if ( !(gridsoul_get_option('hide_post_author')) || !(gridsoul_get_option('hide_posted_date')) || !(gridsoul_get_option('hide_comments_link')) || (!(gridsoul_get_option('hide_post_categories')) && has_category()) || gridsoul_get_option('show_post_edit') ) { ?>
    <div class="gridsoul-entry-meta-single">
    <?php if ( !(gridsoul_get_option('hide_post_author')) ) { ?><span class="gridsoul-entry-meta-single-author gridsoul-entry-meta-single-block"><i class="far fa-user-circle" aria-hidden="true"></i>&nbsp;<span class="author vcard" itemscope="itemscope" itemtype="http://schema.org/Person" itemprop="author"><a class="url fn n" href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>"><?php echo esc_html( get_the_author() ); ?></a></span></span><?php } ?>
    <?php if ( !(gridsoul_get_option('hide_posted_date')) ) { ?><span class="gridsoul-entry-meta-single-date gridsoul-entry-meta-single-block"><i class="far fa-clock" aria-hidden="true"></i>&nbsp;<?php echo esc_html( get_the_date() ); ?></span><?php } ?>
    <?php if ( !(gridsoul_get_option('hide_comments_link')) ) { ?><?php if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) { ?>
    <span class="gridsoul-entry-meta-single-comments gridsoul-entry-meta-single-block"><i class="far fa-comments" aria-hidden="true"></i>&nbsp;<?php comments_popup_link( sprintf( wp_kses( /* translators: %s: post title */ __( 'Leave a Comment<span class="gridsoul-sr-only"> on %s</span>', 'gridsoul' ), array( 'span' => array( 'class' => array(), ), ) ), wp_kses_post( get_the_title() ) ) ); ?></span>
    <?php } ?><?php } ?>
    <?php if ( gridsoul_get_option('show_post_edit') ) { ?><?php edit_post_link( sprintf( wp_kses( /* translators: %s: Name of current post. Only visible to screen readers */ __( 'Edit<span class="gridsoul-sr-only"> %s</span>', 'gridsoul' ), array( 'span' => array( 'class' => array(), ), ) ), wp_kses_post( get_the_title() ) ), '<span class="gridsoul-entry-meta-single-edit-link gridsoul-entry-meta-single-block">&nbsp;&nbsp;<i class="far fa-edit" aria-hidden="true"></i> ', '</span>' ); ?><?php } ?>
    <?php if ( !(gridsoul_get_option('hide_post_categories')) && has_category() ) { ?><?php gridsoul_single_cats(); ?><?php } ?>
    </div>
    <?php } ?>
<?php }
endif;


if ( ! function_exists( 'gridsoul_page_postmeta' ) ) :
function gridsoul_page_postmeta() { ?>
    <?php global $post; ?>
    <?php if ( !(gridsoul_get_option('hide_page_author')) || !(gridsoul_get_option('hide_page_date')) || (!(gridsoul_get_option('hide_page_comments')) && ! post_password_required() && ( comments_open() || get_comments_number() )) ) { ?>
    <?php if ( !((is_front_page()) && (gridsoul_get_option('hide_static_page_meta'))) ) { ?>
    <div class="gridsoul-entry-meta-single">
    <?php if ( !(gridsoul_get_option('hide_page_author')) ) { ?><span class="gridsoul-entry-meta-single-author gridsoul-entry-meta-single-block"><i class="far fa-user-circle" aria-hidden="true"></i>&nbsp;<span class="author vcard" itemscope="itemscope" itemtype="http://schema.org/Person" itemprop="author"><a class="url fn n" href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>"><?php echo esc_html( get_the_author() ); ?></a></span></span><?php } ?>
    <?php if ( !(gridsoul_get_option('hide_page_date')) ) { ?><span class="gridsoul-entry-meta-single-date gridsoul-entry-meta-single-block"><i class="far fa-clock" aria-hidden="true"></i>&nbsp;<?php echo esc_html( get_the_date() ); ?></span><?php } ?>
    <?php if ( !(gridsoul_get_option('hide_page_comments')) ) { ?><?php if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) { ?>
    <span class="gridsoul-entry-meta-single-comments gridsoul-entry-meta-single-block"><i class="far fa-comments" aria-hidden="true"></i>&nbsp;<?php comments_popup_link( sprintf( wp_kses( /* translators: %s: post title */ __( 'Leave a Comment<span class="gridsoul-sr-only"> on %s</span>', 'gridsoul' ), array( 'span' => array( 'class' => array(), ), ) ), wp_kses_post( get_the_title() ) ) ); ?></span>
    <?php } ?><?php } ?>
    </div>
    <?php } ?>
    <?php } ?>
<?php }
endif;